@@ -1,10 +1,10 @@
-__version__ = "0.2.4"
+__version__ = "0.2.5"
 __git_commiter_name__ = "Arnon Yaari"
 __git_commiter_email__ = "arnony@infinidat.com"
-__git_branch__ = '(Not currently on any branch)'
+__git_branch__ = '(detached from v0.2.5)'
 __git_remote_tracking_branch__ = '(No remote tracking)'
 __git_remote_url__ = '(Not remote tracking)'
-__git_head_hash__ = 'ab0568ad35c66db2f657adf60c49171ac72d4c28'
-__git_head_subject__ = 'Finished release v0.2.4.'
+__git_head_hash__ = '8847bceb8aec7284ab30f4d2a5fc159089608cc1'
+__git_head_subject__ = 'update buildout.cfg'
 __git_head_message__ = ''
 __git_dirty_diff__ = ''
\ No newline at end of file
